@@ -76,7 +76,8 @@ class CogEnvDecoder:
         return self._env.close()
 
     def reset(self, fri_cor=0.1, KP=8, KI=0, KD=2, VK1=0.375, M=3.4, Wheel_I=0.0125, enc_noise=0.01, 
-                    control_delay=0.01, lidar_noise=0.03, lidar_lambda=6, obs_mat=False):
+                    control_delay=0.01, lidar_noise=0.03, lidar_lambda=6, obs_mat=False,
+                    blue_pose=[-1.0, -1.0, 0.0], red_pose=[-1.0, -1.0, 0.0]):
 
         if not self._force_sync:
             self._end_thread = True
@@ -92,6 +93,12 @@ class CogEnvDecoder:
         self._engine_Environment_channel.set_float_parameter("M", M)
         self._engine_Environment_channel.set_float_parameter("Wheel_I", Wheel_I)
         self._engine_Environment_channel.set_float_parameter("Encoder_noise", enc_noise)
+        self._engine_Environment_channel.set_float_parameter("blue_x", blue_pose[0])
+        self._engine_Environment_channel.set_float_parameter("blue_y", blue_pose[1])
+        self._engine_Environment_channel.set_float_parameter("blue_yaw", blue_pose[2])
+        self._engine_Environment_channel.set_float_parameter("red_x", red_pose[0])
+        self._engine_Environment_channel.set_float_parameter("red_y", red_pose[1])
+        self._engine_Environment_channel.set_float_parameter("red_yaw", red_pose[2])
 
         self._control_delay = control_delay
         self._lidar_noise = lidar_noise
